#
# spec file for package longhornctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           longhornctl
Version:        1.7.2
Release:        1.1
Summary:        CLI for the Longhorn cloud native distributed block storage
License:        Apache-2.0
URL:            https://github.com/longhorn/cli
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
longhornctl is a CLI (command-line interface) designed to simplify Longhorn
manual operations.

What Can You Do With longhornctl?

* Install and verify prelight requirements.
* Execute one-time Longhorn operations.
* Gain inside into your Longhorn system.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/longhorn/cli/meta.Version=v%{version} \
   -X github.com/longhorn/cli/meta.GitCommit=${COMMIT_HASH} \
   -X github.com/longhorn/cli/meta.BuildDate=${BUILD_DATE}" \
   -o bin/%{name} ./cmd/remote/

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%check
%{buildroot}/%{_bindir}/%{name} version | grep v%{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.2:
  * release: update version file for v1.7.2
  * fix(install/preflight): cos
  * release: update version file for v1.7.2-rc2
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    4c71f1c
  * release: update version file for v1.7.2-rc1
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    a019530
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    3a320d8
  * fix(check): check if module `dm_crypt` is enabled
  * fix(install): enable module `dm_crypt`
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    797b589
  * fix(deps): update k8s.io/utils digest to 49e7df5
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    928beb3
  * fix(deps): update patch digest dependencies to v0.31.1
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    7060fef
  * fix(deps): update module sigs.k8s.io/kustomize/kyaml to v0.17.2
  * fix(deps): update patch digest dependencies
* Wed Sep 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package longhornctl: CLI for the Longhorn cloud native
  distributed block storage
